<?php
//
// $Id: tina_mvc_base_page_class.php, v 0.00 Sat Jan 23 2010 22:02:53 GMT+0000 (IST) Francis Crossen $
//

/**
* The Tina base page class
*
* @package    Tina-MVC
* @subpackage Tina-Core-Classes
*/

/**
 * The Tina base page class
 *
 * Setter and getter for the Wordpress $the_post_title, $the_post_content
 * variables.
 * Also loads HTML templates, merging them with PHP variables
 *
 * @package    Tina-MVC
 * @param   array $request extracted from $_GET - /controller/action/some/data
 * @todo    refining the load_view() method
 * @todo    set the post_title consistently throughout Tina
 */
class tina_mvc_base_page_class {
    
    protected $request, $the_post_title, $the_post_content;
    
    public $role_to_view, $capability_to_view;
    
    function __construct( $request ) {
        
        $this->request = $request;
        
    }
    
    public function get_post_title() {

        return $this->the_post_title;
        
    }
    
    public function get_post_content() {

        return $this->the_post_content;
        
    }
    
    public function set_post_title($str) {
        
        $this->the_post_title = $str;
        
    }
    
    public function set_post_content($str) {
        
        $this->the_post_content = $str;
        
    }
    
/**
 * Include/Parse a HTML file and return as a string
 *
 * Looks for a file in the app or  folders named {$view}_view.php and
 * includes it. Any variables passed in $V are passed to the HTML file in the
 * global scope allowing the use of <?= $V->whatever ? > and 
 *  < ?= $V['array'][0] ? > template constructs.
 * In fact we can use < ? foreach($array as $element): ? > < ? endforeach; ? > 
 * just like in normal PHP mixed HTML/PHP templating.
 * {$view}_view.php is intended to be a HTML file
 *
 * You should use <code>if( !defined('TINA_MVC_LOAD_VIEW') ) die;</code> or something
 * similar to avoid being able to call the template directly.
 *
 * @param   string $view the name of the view file (without '_view.php')
 * @return  mixed $V passed to the included file for parsing
 */
    public function load_view($view=false, $V=false) {
        
        if(!$view) {
            die(__FILE__.' :: '.__FUNCTION__.' ('.__LINE__.') requires $view argument.');
        }
        
        // $view is appended by _view before trying to load it...
        $view_file = $view.'_view.php';
            
        // are we called from a front end controller page?
        if( defined('TINA_MVC_PAGE_CONTROLLER_NAME') ) {
          $my_page_view = TINA_MVC_PAGE_CONTROLLER_NAME."/$view_file";
        }
        elseif( defined('TINA_MVC_PAGE_CONTROLLER_ID') ) {
          // find the page name...
          $tina_pages = get_option('tina_mvc_pages');
          $my_page_view = $tina_pages[TINA_MVC_PAGE_CONTROLLER_ID]['page_name']."/$view_file";
        }
        
        define('TINA_MVC_LOAD_VIEW',true);
        
        if( file_exists( ($inc = tina_mvc_find_app_folder().'/'.$my_page_view) ) ) {
            ob_start();
            include( $inc );
            return ob_get_clean();
        }
        elseif( file_exists( ($inc = tina_mvc_find_app_folder().'/'.$view_file) ) ) {
            ob_start();
            include( $inc );
            return ob_get_clean();
        }
        elseif( file_exists( ($inc = tina_mvc_find_tina_mvc_folder().'/'.$view_file) ) ) {
            ob_start();
            include( $inc );
            return ob_get_clean();
        }
        elseif( is_string($V) ) {
            return $V;
        }
        else {
            $err_msg = __FILE__.' :: '.__FUNCTION__.' ('.__LINE__.')<br />';
            $err_msg .= "View '$view_file' not found. Looked for:<br />";
            $err_msg .= "1) ".tina_mvc_find_app_folder().'/'.$my_page_view."<br />";
            $err_msg .= "2) ".tina_mvc_find_app_folder().'/'.$view_file."<br />";
            $err_msg .= "3) ".tina_mvc_find_tina_mvc_folder().'/'.$view_file."<br />";
            $err_msg .= "Also template variables were not a string and cannot be used in the Wordpress post content. This is what we got:";
            $err_msg .= "<pre><small>".print_r($V,1)."</small></pre>";
            die( $err_msg );
        }
       
    }
    
/**
 * Check if a view file exists
 *
 * Looks for a file in the app folder named {$view}_view.php.
 *
 * @param   string $view the name of the view file (without '_view.php')
 * @return  bool
 * @since   Sun Jan 17 2010 16:47:28 GMT+0000 (IST)
 * @version v 0.00 Sun Jan 17 2010 16:47:28 GMT+0000 (IST)
 */
    public function view_file_exists($view=false) {
        
        if(!$view) {
            die(__FILE__.' :: '.__FUNCTION__.' ('.__LINE__.') requires $view argument.');
        }
        
        // $view is appended by _view before trying to load it...
        $view_file = $view.'_view.php';

        if( file_exists( ( tina_mvc_find_app_folder().'/'.$view_file) ) ) {
          return TRUE;
        }
        elseif( file_exists( ($inc = tina_mvc_find_tina_mvc_folder().'/'.$view_file) ) ) {
          return TRUE;
        }
        else {
          return FALSE;
        }
        
    }

}









?>
